@@ -1,3 +1,4 @@
+import logging
 import threading
 from abc import ABCMeta
 from abc import abstractmethod
@@ -9,6 +10,9 @@ from typing import Dict
 from .build_constants import BUILD_GCLOUD_REST
 
 
+log = logging.getLogger(__name__)
+
+
 class BaseSession:
     __metaclass__ = ABCMeta
 
@@ -55,6 +59,16 @@ class BaseSession:
 if not BUILD_GCLOUD_REST:
     import aiohttp
 
+
+    async def _raise_for_status(resp: aiohttp.ClientResponse) -> None:
+        """Check resp for status and if error log additional info."""
+        try:
+            resp.raise_for_status()
+        except aiohttp.ClientResponseError:
+            log.exception('Error body: %s', await resp.text())
+            raise
+
+
     class AioSession(BaseSession):
         @property
         def session(self) -> aiohttp.ClientSession:
@@ -68,7 +82,7 @@ if not BUILD_GCLOUD_REST:
                        ) -> aiohttp.ClientResponse:
             resp = await self.session.post(url, data=data, headers=headers,
                                            timeout=timeout, params=params)
-            resp.raise_for_status()
+            await _raise_for_status(resp)
             return resp
 
         async def get(self, url: str, headers: Dict[str, str] = None,
@@ -76,14 +90,14 @@ if not BUILD_GCLOUD_REST:
                       ) -> aiohttp.ClientResponse:
             resp = await self.session.get(url, headers=headers, timeout=timeout,
                                           params=params)
-            resp.raise_for_status()
+            await _raise_for_status(resp)
             return resp
 
         async def put(self, url: str, headers: Dict[str, str], data: IOBase,
                       timeout: int = 10) -> aiohttp.ClientResponse:
             resp = await self.session.put(url, data=data, headers=headers,
                                           timeout=timeout)
-            resp.raise_for_status()
+            await _raise_for_status(resp)
             return resp
 
         async def delete(self, url: str, headers: Dict[str, str],
@@ -91,7 +105,7 @@ if not BUILD_GCLOUD_REST:
                          ) -> aiohttp.ClientResponse:
             resp = await self.session.delete(url, headers=headers,
                                              params=params, timeout=timeout)
-            resp.raise_for_status()
+            await _raise_for_status(resp)
             return resp
 
         async def request(self, method: str, url: str, headers: Dict[str, str],
@@ -100,7 +114,7 @@ if not BUILD_GCLOUD_REST:
             resp = await self.session.request(method, url, headers=headers,
                                               **kwargs)
             if auto_raise_for_status:
-                resp.raise_for_status()
+                await _raise_for_status(resp)
             return resp
 
         async def close(self) -> None:
